jenkins-bot merged this change.
[IMPR] Reduce maximum archive size to 200k
Bug: T214669
Change-Id: I8a3ea71150938a502f91c1d29f5e2ee0dbc7d10d
---
M scripts/archivebot.py
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/scripts/archivebot.py b/scripts/archivebot.py
index 66ac3aa..ed1c0ed 100755
--- a/scripts/archivebot.py
+++ b/scripts/archivebot.py
@@ -42,7 +42,7 @@
variable. Will be actualized by bot. Initial value is 1.
maxarchivesize The maximum archive size before incrementing the counter.
Value can be given with appending letter like K or M
which indicates KByte or MByte. Default value is 1000M.
minthreadsleft Minimum number of threads that should be left on a page.
Default value is 5.
minthreadstoarchive The minimum number of threads to archive at once. Default
@@ -90,7 +90,7 @@
"""
#
# (C) Misza13, 2006-2010
-# (C) xqt, 2009-2018
+# (C) xqt, 2009-2019
# (C) Pywikibot team, 2007-2019
#
# Distributed under the terms of the MIT license.
@@ -520,7 +520,7 @@
('archive', ['', False]),
('algo', ['old(24h)', False]),
('counter', ['1', False]),
- ('maxarchivesize', ['1000M', False]),
+ ('maxarchivesize', ['200K', False]),
])
self.salt = salt
self.force = force
@@ -42,7 +42,7 @@
maxarchivesize The maximum archive size before incrementing the counter.
Value can be given with appending letter like K or M
- which indicates KByte or MByte. Default value is 1000M.
+ which indicates KByte or MByte. Default value is 200K.
minthreadsleft Minimum number of threads that should be left on a page.
Default value is 5.
To view, visit change 486716. To unsubscribe, or for help writing mail filters, visit settings.